-----------------------------------------------------------------------------------------------
-- Backdropz by Keaper...
--Simple addon to provide a backdrop on the botton of the screen
-----------------------------------------------------------------------------------------------
require "Apollo"
require "Window"
require "GameLib"
 
-----------------------------------------------------------------------------------------------
-- Backdropz Module Definition
-----------------------------------------------------------------------------------------------
local Backdropz = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999


-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function Backdropz:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	
    return o
end

function Backdropz:Init()

    Apollo.RegisterAddon(self, true)
end

Backdropz.DropSettings = {
	backdrop1 = true,
	backdrop2 = false
}


function Backdropz:OnSave(eType)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Account then return nil end	
		
		local tSavaedData =
		{
			nWindowOpacity = self.nWindowOpacity,
			setAnchorOffsets = self.setAnchorOffsets,
			backDropChoice = self.backDropChoice,
			dropSettings = self.DropSettings
		}
	
		return tSavaedData
end

function Backdropz:OnRestore(eType, tSavedData)
	self.tSavedData = tSavedData
	
	if tSavedData.setAnchorOffsets then
		self.setAnchorOffsets = tSavedData.setAnchorOffsets
	end
	
	if tSavedData.nWindowOpacity then
		self.nWindowOpacity = tSavedData.nWindowOpacity 
	end
	
	if tSavedData.BackDropChoice then
		self.backDropChoice = tSavedData.backDropChoice
	end
	
	if tSavedData.dropSettings then
		for k, v in pairs(tSavedData.dropSettings) do
			self.DropSettings[k] = v
		end
	end	
	
end



-----------------------------------------------------------------------------------------------
-- Backdropz OnLoad
-----------------------------------------------------------------------------------------------
function Backdropz:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("Backdropz.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
	
end

-----------------------------------------------------------------------------------------------
-- Backdropz OnDocLoaded
-----------------------------------------------------------------------------------------------

function Backdropz:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "arts", "FixedHudStratumLow", self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
			    	
	
		self.wndMenu = Apollo.LoadForm(self.xmlDoc, "Menu", nil, self)
		
		self.wndMenu:Show(false)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("bd", "OnBackdropzOn", self)

		-- Do additional Addon initialization here
		--self.wndMain:Invoke()
		
	end
	
	self.wndMain:Show(true, true)
	
		
	if self.BackDropChoice then
		self.wndMain:FindChild(self.backDropChoice):Show(true)
	else
		self.backDropChoice = "backdrop1"
	end
	
	

		

	self:Update()
end


----------------------------------------------------------------
-- Art hooks
------------------------------------------------





-----------------------------------------------------------------------------------------------
-- Backdropz Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here
function Backdropz:Update()
	for k, v in pairs(self.DropSettings) do
		if v then
			self.backDropChoice = k
			self.wndMain:FindChild(self.backDropChoice):Show(true, true)
		else
			self.backDropHide = k
			self.wndMain:FindChild(self.backDropHide):Show(false, false)
		end
	end
	
	Backdropz.backdrop1 = self.wndMenu:FindChild("Choice1")
	Backdropz.backdrop2 = self.wndMenu:FindChild("Choice2")
	self.backdrop1:SetCheck(self.DropSettings.backdrop1)
	self.backdrop2:SetCheck(self.DropSettings.backdrop2)
	
	if self.nWindowOpacity then
		self.wndMain:FindChild(self.backDropChoice):SetOpacity(self.nWindowOpacity)
	else
		self.nWindowOpacity = 1.0
	end
	
	
	if self.setAnchorOffsets then
		self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
	end
	self.wndMain:FindChild(self.backDropChoice):SetOpacity(self.nWindowOpacity)
	self.wndMenu:FindChild("SliderBar"):SetValue(self.nWindowOpacity * 100)
	self:UpdateConfiguration()
end

function Backdropz:UpdateConfiguration()
	_OpacitySlider = self.wndMenu:FindChild("OpacitySlider")
	if (_OpacitySlider ~= nil) then
		local l_sliderVal = _OpacitySlider:FindChild("SliderBar"):GetValue()
		_OpacitySlider:SetProgress(l_sliderVal / 100)
		_OpacitySlider:FindChild("TextValue"):SetText(l_sliderVal .. "%")
	end
	
	
end

-- on SlashCommand "/bd"
function Backdropz:OnBackdropzOn()
	self.wndMenu:Invoke() -- show the window
	
	
end

-----------------------------------------------------------------------------------------------
-- BackdropzForm Functions
-----------------------------------------------------------------------------------------------
function Backdropz:OnClose()
	self.wndMenu:Show(false, false)
end

function Backdropz:WndUp()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[2] - 1
	local newoffset2 = currentOffsets[4] - 1
	
	self.setAnchorOffsets = { currentOffsets[1], newoffset1, currentOffsets[3], newoffset2 }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndBigUp()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[2] - 7
	local newoffset2 = currentOffsets[4] - 7
	
	self.setAnchorOffsets = { currentOffsets[1], newoffset1, currentOffsets[3], newoffset2 }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end


function Backdropz:WndDown()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[2] + 1
	local newoffset2 = currentOffsets[4] + 1
	
	self.setAnchorOffsets = { currentOffsets[1], newoffset1, currentOffsets[3], newoffset2 }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndBigDown()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[2] + 7
	local newoffset2 = currentOffsets[4] + 7
	
	self.setAnchorOffsets = { currentOffsets[1], newoffset1, currentOffsets[3], newoffset2 }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndLeft()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[1] - 1
	local newoffset2 = currentOffsets[3] - 1
	
	self.setAnchorOffsets = { newoffset1, currentOffsets[2], newoffset2, currentOffsets[4] }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndBigLeft()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[1] - 7
	local newoffset2 = currentOffsets[3] - 7
	
	self.setAnchorOffsets = { newoffset1, currentOffsets[2], newoffset2, currentOffsets[4] }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndRight()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[1] + 1
	local newoffset2 = currentOffsets[3] + 1
	
	self.setAnchorOffsets = { newoffset1, currentOffsets[2], newoffset2, currentOffsets[4] }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

function Backdropz:WndBigRight()
	local currentOffsets = { self.wndMain:FindChild(self.backDropChoice):GetAnchorOffsets() }
	local newoffset1 = currentOffsets[1] + 7
	local newoffset2 = currentOffsets[3] + 7
	
	self.setAnchorOffsets = { newoffset1, currentOffsets[2], newoffset2, currentOffsets[4] }
	self.wndMain:FindChild(self.backDropChoice):SetAnchorOffsets(unpack(self.setAnchorOffsets))
end

---------------------------------------------------------------------------------------------------
-- Menu Functions
---------------------------------------------------------------------------------------------------



function Backdropz:SlideChange( wndHandler, wndControl, fNewValue, fOldValue )
self.nWindowOpacity = fNewValue / 100
self.wndMain:FindChild(self.backDropChoice):SetOpacity(self.nWindowOpacity)
self:Update()
end

function Backdropz:OnButtonClick1()
	for k, v in pairs(self.DropSettings) do
			self.DropSettings[k] = false
	end
	if self.backdrop1:IsChecked() then
		self.backdrop2:SetCheck(false)
		self.DropSettings.backdrop1 = true
	end
	self:Update()
end

function Backdropz:OnButtonClick2()
	for k, v in pairs(self.DropSettings) do
			self.DropSettings[k] = false
	end
	if self.backdrop2:IsChecked() then
		self.backdrop1:SetCheck(false)
		self.DropSettings.backdrop2= true
		
	end
	self:Update()
end

-----------------------------------------------------------------------------------------------
-- Backdropz Instance
-----------------------------------------------------------------------------------------------
local BackdropzInst = Backdropz:new()
BackdropzInst:Init()
